DataExplorerTheme class

Theme used to display the JsonDataExplorer.

Annotations

Constructors

DataExplorerTheme({TextStyle? rootKeyTextStyle, TextStyle? propertyKeyTextStyle, TextStyle? keySearchHighlightTextStyle, TextStyle? valueTextStyle, TextStyle? valueSearchHighlightTextStyle, TextStyle? focusedKeySearchHighlightTextStyle, TextStyle? focusedValueSearchHighlightTextStyle, Color indentationLineColor = Colors.grey, Color? highlightColor, double indentationPadding = 8.0, double propertyIndentationPaddingFactor = 4})

Properties

focusedKeySearchNodeHighlightTextStyle → TextStyle
Text style used to highlight the current focused search result node key.
final
focusedValueSearchHighlightTextStyle → TextStyle
Text style used to highlight the current focused search result node value.
final
hashCode → int
The hash code for this object.
no setteroverride
highlightColor → Color?
Cursor hover highlight color.
final
indentationLineColor → Color
Indentation lines color.
final
indentationPadding → double
Padding used to indent nodes.
final
keySearchHighlightTextStyle → TextStyle
Text style use to highlight search result matches on json attribute keys.
final
propertyIndentationPaddingFactor → double
An extra factor applied on indentationPadding used when rendering properties.
final
propertyKeyTextStyle → TextStyle
Text style used to display json property key attributes.
final
rootKeyTextStyle → TextStyle
Text style used to display json class/arrays key attributes.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
valueSearchHighlightTextStyle → TextStyle
Text style use to highlight search result matches on json attribute values.
final
valueTextStyle → TextStyle
Text style to display the values of of json attributes.
final

Methods

copyWith({TextStyle? rootKeyTextStyle, TextStyle? propertyKeyTextStyle, TextStyle? keySearchHighlightTextStyle, TextStyle? valueTextStyle, TextStyle? valueSearchHighlightTextStyle, TextStyle? focusedKeySearchNodeHighlightTextStyle, TextStyle? focusedValueSearchHighlightTextStyle, Color? indentationLineColor, Color? highlightColor, double? indentationPadding, double? propertyIndentationPaddingFactor}) → DataExplorerTheme
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

defaultTheme → const DataExplorerTheme
Default theme used if no theme is set.