PropertyOverrides class

Holds information about a property value style and interaction.

Constructors

PropertyOverrides({required TextStyle style, VoidCallback? onTap})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
onTap → VoidCallback?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → TextStyle
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited